@@ -568,26 +568,26 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
             )
 
             if protocol == 'remote':
-                manager_cmd = ["ssh", remote_machine, "stat", macname]
+                manager_cmd = ["ssh", remote_machine, "date", "-r", macname, "+%H:%M"]
                 chk_time_cmd = "ssh " + remote_machine + " echo $(date +%H:%M)"
             elif protocol == 'remote-sharedfs':
-                manager_cmd = ["stat", macname_sf]
+                manager_cmd = ["date", "-r", macname_sf, "+%H:%M"]
                 chk_time_cmd = "echo $(date +%H:%M)"
             elif protocol == 'local':
-                manager_cmd = ["stat", macname]
+                manager_cmd = ["date", "-r", macname, "+%H:%M"]
                 chk_time_cmd = "echo $(date +%H:%M)"
             if DEBUG:
                 print("COMMAND", manager_cmd)
                 touch_time_txt = subprocess.Popen(
                     manager_cmd,
                     stdout=subprocess.PIPE
-                ).stdout.read().decode('ascii')
+                ).stdout.read().decode('utf-8')
             else:
                 touch_time_txt = subprocess.Popen(
                     manager_cmd, 
                     stderr=devnull, 
                     stdout=subprocess.PIPE
-                ).stdout.read().decode('ascii')
+                ).stdout.read().decode('utf-8')
             if touch_time_txt.strip():
                 if DEBUG:
                     print("COMMAND", chk_time_cmd)
@@ -603,16 +603,7 @@ def remote_job_control(protocol_triad, batch_job_code, fs_locations, tasks_per_j
                         stdout=subprocess.PIPE, 
                         shell=True
                     ).stdout.read().decode('ascii').split()[0].split(":")
-                touch_time = -9999
-                for line in touch_time_txt.split('\n'):
-                    fields = line.split()
-                    if fields[0] == "Modify:":
-                        ff = fields[2].split(":")
-                        touch_time = int(ff[0])*60 + int(ff[1])
-                        break
-                if touch_time == -9999:
-                    print("ERROR reading {0}\n{1}".format(manager_cmd, touch_time_txt))
-                    exit(1)
+                touch_time = int(touch_time_txt.split(":")[0])*60 + int(touch_time_txt.split(":")[1])
                 local_time = int(local_time_l[0])*60 + int(local_time_l[1])
                 coeff = (local_time - touch_time)%(24*60)
                 is_active = False if coeff > 1 else True
@@ -812,11 +803,9 @@ def gather_results(protocol_triad, cache_dir, job_data, batch_job_code,
         with open(snap_log, 'w') as snapf:
             # Creates all new folders
             for d in sorted(newly_added):
-                if not newly_added[d]:
+                if protocol != 'local' and not os.path.exists(build_envroot+d):
                     snapf.write("Directory created: {0}\n".format(build_envroot+d))
-                    if protocol != 'local':
-                        if not os.path.exists(build_envroot+d):
-                            os.mkdir(build_envroot+d)
+                    os.mkdir(build_envroot+d)
 
             # Populates new and old folders
             for d in sorted(newly_added):
@@ -859,19 +848,7 @@ def take_snapshot(protocol_triad, root_dir):
     protocol, remote_machine, hpc_shared_folder = protocol_triad
     devnull = open('/dev/null', 'w')
 
-    """
-    for treedir, files in tree:
-        for f in files:
-            if f == "*":
-                lsrcmd = ["ls", "-ltrh",treedir]
-            elif f == "**":
-                lsrcmd = ["ls", "-ltrhR",treedir]
-##### ARRIVATO QUI
-    """
-
     lsrcmd = ["ls", "-ltrhR", root_dir]
-#    if remote_machine:
-#        lsrcmd = ["ssh", remote_machine] + lsrcmd
 
     if DEBUG:
         print("COMMAND", lsrcmd)
@@ -881,7 +858,7 @@ def take_snapshot(protocol_triad, root_dir):
         textlines = subprocess.Popen(lsrcmd, 
             stdout=subprocess.PIPE, stderr=devnull).stdout.readlines()
 
-    snapshot = {}
+    snapshot = {"::NEGLECT::" : []}
     for l in textlines:
         line = l.decode('ascii')
         if not line.strip() or line.startswith('total'):
@@ -894,6 +871,10 @@ def take_snapshot(protocol_triad, root_dir):
             filename = filename.replace(root_dir,"")
             if priv.startswith('-'):  # If item is not a folder
                 snapshot[dirname][filename] = (priv, usr1, usr2, s, d1, d2, d3)
+        elif len(line.split()) == 11 and line[9].split() == "->":
+            priv, _, usr1, usr2, s, d1, d2, d3, filename, _, slink = line.split()
+            filename = filename.replace(root_dir,"")
+            snapshot["::NEGLECT::"].append(filename)
         else:
             print(("WARNING (take_snapshot): output of ls -ltrhR is not"
                 "in the expected format"))
@@ -905,11 +886,11 @@ def take_snapshot(protocol_triad, root_dir):
 def compare_snapshots(snap1, snap2):
     newtosnap2 = {}
     for d in snap2:
-        if d not in snap1:
+        if d not in snap1 and d not in snap1["::NEGLECT::"]:
             newtosnap2[d] = snap2[d]
             continue
         for f in snap2[d]:
-            if f not in snap1[d]:
+            if f not in snap1[d] and f not in snap1["::NEGLECT::"]:
                 if d not in newtosnap2:
                     newtosnap2[d] = []
                 newtosnap2[d].append(f)
